==> tutti-ui-swing-3.1.3-sources.jar: fr/ifremer/tutti/ui/swing/action/RenameSpeciesBatchAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: RenameSpeciesBatchAction.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/tutti/tags/tutti-3.1.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/RenameSpeciesBatchAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.Lists;
import fr.ifremer.tutti.persistence.entities.data.SampleCategory;
import fr.ifremer.tutti.persistence.entities.referential.CaracteristicQualitativeValue;
import fr.ifremer.tutti.persistence.entities.referential.Species;
import fr.ifremer.tutti.service.PersistenceService;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchRowModel;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchTableModel;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIHandler;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIModel;
import jaxx.runtime.SwingUtil;
import org.jdesktop.swingx.JXTable;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

import static org.nuiton.i18n.I18n.t;

/**
 * To rename the species for a species batch and all his children.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class RenameSpeciesBatchAction extends AbstractTuttiAction<SpeciesBatchUIModel, SpeciesBatchUI, SpeciesBatchUIHandler> {

    protected Species selectedSpecies;

    public RenameSpeciesBatchAction(SpeciesBatchUIHandler handler) {
        super(handler, false);

    }

    @Override
    public boolean prepareAction() throws Exception {
        boolean result = super.prepareAction();

        SpeciesBatchTableModel tableModel = handler.getTableModel();
        JXTable table = handler.getTable();
        int selectedRowIndex = SwingUtil.getSelectedModelRow(table);
        SpeciesBatchRowModel row = tableModel.getEntry(selectedRowIndex);

        SpeciesBatchUIModel model = handler.getModel();
        List<Species> speciesList = Lists.newArrayList(
                getDataContext().getReferentSpeciesWithSurveyCode());
        SampleCategory<?> firstSampleCategory = row.getFirstSampleCategory();
        Serializable categoryValue = firstSampleCategory.getCategoryValue();
        speciesList.removeAll(
                model.getSpeciesUsed().get((CaracteristicQualitativeValue) categoryValue));

        selectedSpecies = getHandler().openAddSpeciesDialog(
                t("tutti.selectSpecies.title"),
                speciesList
        );

        result &= selectedSpecies != null;
        return result;
    }

    @Override
    public void releaseAction() {
        selectedSpecies = null;
        super.releaseAction();
    }

    @Override
    public void doAction() throws Exception {

        SpeciesBatchTableModel tableModel = handler.getTableModel();
        JXTable table = handler.getTable();
        int selectedRowIndex = SwingUtil.getSelectedModelRow(table);
        SpeciesBatchRowModel row = tableModel.getEntry(selectedRowIndex);

        PersistenceService persistenceService = getContext().getPersistenceService();
        persistenceService.changeSpeciesBatchSpecies(row.getId(), selectedSpecies);

        SampleCategory<?> firstSampleCategory = row.getFirstSampleCategory();
        Serializable categoryValue = firstSampleCategory.getCategoryValue();

        Collection<Species> speciesUsed = getModel().getSpeciesUsed()
                .get((CaracteristicQualitativeValue) categoryValue);
        speciesUsed.remove(row.getSpecies());
        changeChildrenSpecies(row, selectedSpecies);
        speciesUsed.add(selectedSpecies);
    }

    protected void changeChildrenSpecies(SpeciesBatchRowModel row,
                                         Species species) {
        row.setSpecies(species);
        List<SpeciesBatchRowModel> children = row.getChildBatch();
        if (children != null) {
            for (SpeciesBatchRowModel child : children) {
                changeChildrenSpecies(child, species);
            }
        }
    }
}

==> tutti-ui-swing-3.2-sources.jar: fr/ifremer/tutti/ui/swing/action/RenameSpeciesBatchAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: RenameSpeciesBatchAction.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.2/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/RenameSpeciesBatchAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.Lists;
import fr.ifremer.tutti.persistence.entities.data.SampleCategory;
import fr.ifremer.tutti.persistence.entities.referential.CaracteristicQualitativeValue;
import fr.ifremer.tutti.persistence.entities.referential.Species;
import fr.ifremer.tutti.service.PersistenceService;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchRowModel;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchTableModel;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIHandler;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIModel;
import jaxx.runtime.SwingUtil;
import org.jdesktop.swingx.JXTable;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

import static org.nuiton.i18n.I18n.t;

/**
 * To rename the species for a species batch and all his children.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class RenameSpeciesBatchAction extends AbstractTuttiAction<SpeciesBatchUIModel, SpeciesBatchUI, SpeciesBatchUIHandler> {

    protected Species selectedSpecies;

    public RenameSpeciesBatchAction(SpeciesBatchUIHandler handler) {
        super(handler, false);

    }

    @Override
    public boolean prepareAction() throws Exception {
        boolean result = super.prepareAction();

        SpeciesBatchTableModel tableModel = handler.getTableModel();
        JXTable table = handler.getTable();
        int selectedRowIndex = SwingUtil.getSelectedModelRow(table);
        SpeciesBatchRowModel row = tableModel.getEntry(selectedRowIndex);

        SpeciesBatchUIModel model = handler.getModel();
        List<Species> speciesList = Lists.newArrayList(
                getDataContext().getReferentSpeciesWithSurveyCode());
        SampleCategory<?> firstSampleCategory = row.getFirstSampleCategory();
        Serializable categoryValue = firstSampleCategory.getCategoryValue();
        speciesList.removeAll(
                model.getSpeciesUsed().get((CaracteristicQualitativeValue) categoryValue));

        selectedSpecies = getHandler().openAddSpeciesDialog(
                t("tutti.selectSpecies.title"),
                speciesList
        );

        result &= selectedSpecies != null;
        return result;
    }

    @Override
    public void releaseAction() {
        selectedSpecies = null;
        super.releaseAction();
    }

    @Override
    public void doAction() throws Exception {

        SpeciesBatchTableModel tableModel = handler.getTableModel();
        JXTable table = handler.getTable();
        int selectedRowIndex = SwingUtil.getSelectedModelRow(table);
        SpeciesBatchRowModel row = tableModel.getEntry(selectedRowIndex);

        PersistenceService persistenceService = getContext().getPersistenceService();
        persistenceService.changeSpeciesBatchSpecies(row.getId(), selectedSpecies);

        SampleCategory<?> firstSampleCategory = row.getFirstSampleCategory();
        Serializable categoryValue = firstSampleCategory.getCategoryValue();

        Collection<Species> speciesUsed = getModel().getSpeciesUsed()
                .get((CaracteristicQualitativeValue) categoryValue);
        speciesUsed.remove(row.getSpecies());
        changeChildrenSpecies(row, selectedSpecies);
        speciesUsed.add(selectedSpecies);
    }

    protected void changeChildrenSpecies(SpeciesBatchRowModel row,
                                         Species species) {
        row.setSpecies(species);
        List<SpeciesBatchRowModel> children = row.getChildBatch();
        if (children != null) {
            for (SpeciesBatchRowModel child : children) {
                changeChildrenSpecies(child, species);
            }
        }
    }
}
